@@ -32,7 +32,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         If auto-configure is enabled, the changes take immediate effect.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *reset* operation.
+            DwfLibraryError: An error occurred while executing the *reset* operation.
         """
         result = self.lib.FDwfAnalogIOReset(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -42,7 +42,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         """Configure the |AnalogIO| functionality.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *configure* operation.
+            DwfLibraryError: An error occurred while executing the *configure* operation.
         """
         result = self.lib.FDwfAnalogIOConfigure(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -58,7 +58,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         so this method does not return a value.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *status* operation.
+            DwfLibraryError: An error occurred while executing the *status* operation.
         """
         result = self.lib.FDwfAnalogIOStatus(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -79,7 +79,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             The elements indicate whether Master Enable *set* and *status* are supported by the |AnalogIO| device.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_set_supported = typespec_ctypes.c_int()
         c_status_supported = typespec_ctypes.c_int()
@@ -97,7 +97,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             master_enable (bool): The new value of the Master Enable setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfAnalogIOEnableSet(self.hdwf, master_enable)
         if result != RESULT_SUCCESS:
@@ -112,7 +112,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             The value of the Master Enable setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_master_enable = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogIOEnableGet(self.hdwf, c_master_enable)
@@ -131,7 +131,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             bool: the current status of the Master Enable.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_master_enable_status = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogIOEnableStatus(self.hdwf, c_master_enable_status)
@@ -147,7 +147,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             int: The number of |AnalogIO| channels.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_channel_count = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogIOChannelCount(self.hdwf, c_channel_count)
@@ -166,7 +166,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             Tuple[str, str]: The name and label of the channel.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_channel_name = ctypes.create_string_buffer(32)
         c_channel_label = ctypes.create_string_buffer(16)
@@ -191,7 +191,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             int: The number of nodes associated to the channel.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_node_count = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogIOChannelInfo(self.hdwf, channel_index, c_node_count)
@@ -210,7 +210,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             Tuple[str, str]: The name and unit of the quantity associated with the node.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_node_name = ctypes.create_string_buffer(32)
         c_node_units = ctypes.create_string_buffer(16)
@@ -237,7 +237,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             DwfAnalogIO: The type of quantity represented by the node.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_analog_io = typespec_ctypes.DwfAnalogIO()
         result = self.lib.FDwfAnalogIOChannelNodeInfo(
@@ -268,7 +268,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             and the number of resolution steps.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_min_value = typespec_ctypes.c_double()
         c_max_value = typespec_ctypes.c_double()
@@ -296,7 +296,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             node_value (float): The value we want to set the node to.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfAnalogIOChannelNodeSet(
             self.hdwf,
@@ -314,7 +314,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             node_index (int): The node from which we want to get the currently configured value.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_node_value = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogIOChannelNodeGet(
@@ -339,7 +339,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             and the number of resolution steps.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_min_value = typespec_ctypes.c_double()
         c_max_value = typespec_ctypes.c_double()
@@ -367,7 +367,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             float: the most recent value read for this nodes.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_node_value = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogIOChannelNodeStatus(
