@@ -2,14 +2,14 @@
 
 from typing import Optional
 
-from pydwf.core.dwf_library_subapi import DwfLibrarySubApi
+from pydwf.core.dwf_library_subapi import AbstractDwfLibrarySubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.dwf_device import DwfDevice
 
 
-class DeviceControl(DwfLibrarySubApi):
+class DeviceControl(AbstractDwfLibrarySubApi):
     """The |DeviceControl| class provides access to the device control functionality of a
     |DwfLibrary:link|.
 
@@ -28,21 +28,21 @@ class DeviceControl(DwfLibrarySubApi):
             into a single method. The call that is actually made depends on the value of the *config_index* parameter.
 
         Note:
-            This method takes approximately 2 seconds to complete.
+            This method can take several seconds to complete.
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device (see the
-                |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                |DeviceEnum.enumerateDevices:link| method).
 
                 To automatically enumerate all connected devices and open the first discovered device,
                 use the value -1 for this parameter.
 
             config_index (Optional[int]): Zero-based index of the device configuration to use
-                (see the |DwfLibrary.deviceEnum.enumerateConfigurations:link| method).
+                (see the |DeviceEnum.enumerateConfigurations:link| method).
                 If None, open the default (first) device configuration.
 
         See also:
-            The |pydwf.utilities.open_dwf_device:link| function provides a more powerful way to select and open
+            The |pydwf.utilities.openDwfDevice:link| function provides a more powerful way to select and open
             a device and configuration.
 
         Returns:
