@@ -39,7 +39,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         If auto-configure is enabled, the reset values will be used immediately.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *reset* operation.
+            DwfLibraryError: An error occurred while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalInReset(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -53,7 +53,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             start (bool): If True, an acquisition is started. If False, an ongoing acquisition is stopped.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *configure* operation.
+            DwfLibraryError: An error occurred while executing the *configure* operation.
         """
         result = self.lib.FDwfDigitalInConfigure(self.hdwf, reconfigure, start)
         if result != RESULT_SUCCESS:
@@ -69,7 +69,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             DwfState: The current state of the instrument.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *status* operation.
+            DwfLibraryError: An error occurred while executing the *status* operation.
         """
         c_status = typespec_ctypes.DwfState()
         result = self.lib.FDwfDigitalInStatus(self.hdwf, read_data_flag, c_status)
@@ -96,7 +96,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             for all three tuple elements.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_sec_utc = typespec_ctypes.c_unsigned_int()
         c_tick = typespec_ctypes.c_unsigned_int()
@@ -120,14 +120,14 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             bool: True if the current acquisition is auto-triggered, False otherwise.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while retrieving the auto-triggered status.
         """
-        c_auto = typespec_ctypes.c_int()
-        result = self.lib.FDwfDigitalInStatusAutoTriggered(self.hdwf, c_auto)
+        c_auto_triggered = typespec_ctypes.c_int()
+        result = self.lib.FDwfDigitalInStatusAutoTriggered(self.hdwf, c_auto_triggered)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        auto = bool(c_auto.value)
-        return auto
+        auto_triggered = bool(c_auto_triggered.value)
+        return auto_triggered
 
     def statusSamplesLeft(self) -> int:
         """Retrieve the number of samples left in the acquisition.
@@ -137,7 +137,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             remaining to be acquired in the acquisition.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_samplesLeft = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInStatusSamplesLeft(self.hdwf, c_samplesLeft)
@@ -153,7 +153,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The number of valid samples.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_samples_valid = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInStatusSamplesValid(self.hdwf, c_samples_valid)
@@ -172,7 +172,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The buffer write index.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_index_write = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInStatusIndexWrite(self.hdwf, c_index_write)
@@ -186,10 +186,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
 
         Returns:
             Tuple[int, int, int]: A three-element tuple containing the counts for
-                *available*, *lost*, and *corrupt* data samples, in that order.
+            *available*, *lost*, and *corrupt* data samples, in that order.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_data_available = typespec_ctypes.c_int()
         c_data_lost = typespec_ctypes.c_int()
@@ -220,7 +220,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Figure out data format.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         samples = np.empty(count_bytes, dtype='B')
         result = self.lib.FDwfDigitalInStatusData(
@@ -238,7 +238,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Figure out data format.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         samples = np.empty(count_bytes, dtype='B')
         result = self.lib.FDwfDigitalInStatusData2(
@@ -257,7 +257,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Figure out data format.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         noise = np.empty(count_bytes, dtype='B')
         result = self.lib.FDwfDigitalInStatusNoise2(
@@ -278,7 +278,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             The internal clock frequency, in Hz.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_hzFreq = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalInInternalClockInfo(self.hdwf, c_hzFreq)
@@ -294,7 +294,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             List[DwfDigitalInClockSource]: A list of valid clock sources.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_clock_source_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInClockSourceInfo(self.hdwf, c_clock_source_bitset)
@@ -312,7 +312,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             clock_source (DwfDigitalInClockSource): The clock source to be selected.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInClockSourceSet(self.hdwf, clock_source.value)
         if result != RESULT_SUCCESS:
@@ -325,7 +325,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             DwfDigitalInClockSource: The currently configured |DigitalIn| clock source.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_clock_source = typespec_ctypes.DwfDigitalInClockSource()
         result = self.lib.FDwfDigitalInClockSourceGet(self.hdwf, c_clock_source)
@@ -343,7 +343,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The maximum valid divider value that can be configured.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_divider_max = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalInDividerInfo(self.hdwf, c_divider_max)
@@ -359,7 +359,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             divider: The divider value to be configured.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInDividerSet(self.hdwf, divider)
         if result != RESULT_SUCCESS:
@@ -372,7 +372,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The currently configured divider value.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_divider = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalInDividerGet(self.hdwf, c_divider)
@@ -390,7 +390,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             The number of digital input bits available.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_num_bits = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInBitsInfo(self.hdwf, c_num_bits)
@@ -408,7 +408,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             num_bits (int): The number of bits per sample (8, 16, or 32).
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInSampleFormatSet(self.hdwf, num_bits)
         if result != RESULT_SUCCESS:
@@ -421,7 +421,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The currently configured number of bits per sample (8, 16, or 32).
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_num_bits = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInSampleFormatGet(self.hdwf, c_num_bits)
@@ -442,7 +442,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         Valid only for the Digital Discovery device.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInInputOrderSet(self.hdwf, dio_first)
         if result != RESULT_SUCCESS:
@@ -457,7 +457,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The maximum valid buffer size.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_buffer_size_max = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInBufferSizeInfo(self.hdwf, c_buffer_size_max)
@@ -473,7 +473,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             buffer_size (int): The buffer size to be configured.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInBufferSizeSet(self.hdwf, buffer_size)
         if result != RESULT_SUCCESS:
@@ -486,7 +486,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The currently configured buffer size.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_buffer_size = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInBufferSizeGet(self.hdwf, c_buffer_size)
@@ -502,7 +502,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             List[DwfDigitalInSampleMode]: A list of valid sample modes.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_sample_mode_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInSampleModeInfo(self.hdwf, c_sample_mode_bitset)
@@ -520,7 +520,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             sample_mode (DwfDigitalInSampleMode): The sample mode to be configured.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInSampleModeSet(self.hdwf, sample_mode.value)
         if result != RESULT_SUCCESS:
@@ -533,7 +533,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             DwfDigitalInSampleMode: The currently configured sample mode.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_sample_mode = typespec_ctypes.DwfDigitalInSampleMode()
         result = self.lib.FDwfDigitalInSampleModeGet(self.hdwf, c_sample_mode)
@@ -552,7 +552,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Figure out what this setting does.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInSampleSensibleSet(self.hdwf, compression_bits)
         if result != RESULT_SUCCESS:
@@ -568,7 +568,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Figure out what this setting does.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_compression_bits = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalInSampleSensibleGet(self.hdwf, c_compression_bits)
@@ -584,7 +584,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             List[DwfAcquisitionMode]: A list of valid acquisition modes.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_acquisition_mode_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInAcquisitionModeInfo(self.hdwf, c_acquisition_mode_bitset)
@@ -602,7 +602,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             acquisition_mode (DwfAcquisitionMode): The acquisition mode to be configured.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInAcquisitionModeSet(self.hdwf, acquisition_mode.value)
         if result != RESULT_SUCCESS:
@@ -615,7 +615,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             DwfAcquisitionMode: The currently active acquisition mode.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_acquisition_mode = typespec_ctypes.DwfAcquisitionMode()
         result = self.lib.FDwfDigitalInAcquisitionModeGet(self.hdwf, c_acquisition_mode)
@@ -640,7 +640,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             List[DwfTriggerSource]: A list of valid trigger source options.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_trigger_source_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalInTriggerSourceInfo(self.hdwf, c_trigger_source_bitset)
@@ -658,7 +658,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             trigger_source (DwfTriggerSource): The trigger source to be configured.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerSourceSet(self.hdwf, trigger_source.value)
         if result != RESULT_SUCCESS:
@@ -671,7 +671,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             DwfTriggerSource: The currently configured |DigitalIn| trigger source.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_trigger_source = typespec_ctypes.DwfTriggerSource()
         result = self.lib.FDwfDigitalInTriggerSourceGet(self.hdwf, c_trigger_source)
@@ -687,7 +687,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The maximum number of samples after the trigger.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_max_samples_after_trigger = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalInTriggerPositionInfo(
@@ -705,7 +705,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             samples_after_trigger (int): The number of samples after the trigger.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerPositionSet(self.hdwf, samples_after_trigger)
         if result != RESULT_SUCCESS:
@@ -718,7 +718,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The currently configured number of samples after the trigger.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_samples_after_trigger = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalInTriggerPositionGet(self.hdwf, c_samples_after_trigger)
@@ -734,7 +734,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Tuple[float, float, int]: The range and number of steps of the auto-timeout setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_trigger_auto_timeout_min = typespec_ctypes.c_double()
         c_trigger_auto_timeout_max = typespec_ctypes.c_double()
@@ -762,7 +762,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             auto_timeout (float): The auto-timeout value to be configured, in seconds.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerAutoTimeoutSet(self.hdwf, auto_timeout)
         if result != RESULT_SUCCESS:
@@ -775,7 +775,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             float: The currently configured trigger auto-timeout value, in seconds.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_auto_timeout = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalInTriggerAutoTimeoutGet(self.hdwf, c_auto_timeout)
@@ -797,7 +797,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             trigger_slope (DwfTriggerSlope): The trigger slope to be configured.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerSlopeSet(self.hdwf, trigger_slope.value)
         if result != RESULT_SUCCESS:
@@ -810,7 +810,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             DwfTriggerSlope: The currently configured trigger slope.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_trigger_slope = typespec_ctypes.DwfTriggerSlope()
         result = self.lib.FDwfDigitalInTriggerSlopeGet(self.hdwf, c_trigger_slope)
@@ -826,7 +826,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             samples_before_trigger (int): The prefill count, in samples.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerPrefillSet(self.hdwf, samples_before_trigger)
         if result != RESULT_SUCCESS:
@@ -839,7 +839,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             int: The trigger prefill count, in samples.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_samples_before_trigger = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalInTriggerPrefillGet(self.hdwf, c_samples_before_trigger)
@@ -855,7 +855,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Tuple[int, int, int, int]: (to be documented)
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_fsLevelLow  = typespec_ctypes.c_unsigned_int()
         c_fsLevelHigh = typespec_ctypes.c_unsigned_int()
@@ -885,7 +885,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             edge_fall (int): Bit-field; channels that trigger at a falling edge.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerSet(
             self.hdwf,
@@ -903,7 +903,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Tuple[int, int, int, int]: bitfields for level_low, level_high, edge_rise, edge_fall sensitivity.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_level_low  = typespec_ctypes.c_unsigned_int()
         c_level_high = typespec_ctypes.c_unsigned_int()
@@ -933,7 +933,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             edge_fall (int):  (to be documented)
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerResetSet(
             self.hdwf,
@@ -952,7 +952,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             restart (int): (to be documented)
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerCountSet(self.hdwf, count, restart)
         if result != RESULT_SUCCESS:
@@ -967,7 +967,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             index_sync (int): (to be documented)
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerLengthSet(self.hdwf, trigger_length_min, trigger_length_max, index_sync)
         if result != RESULT_SUCCESS:
@@ -983,7 +983,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             bit_stuffing (int): (to be documented)
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInTriggerMatchSet(self.hdwf, pin, mask, value, bit_stuffing)
         if result != RESULT_SUCCESS:
@@ -1004,7 +1004,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             This function is OBSOLETE.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalInMixedSet(self.hdwf, enable)
         if result != RESULT_SUCCESS:
