@@ -29,7 +29,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
         If auto-configure is enabled, the values are immediately effectuated.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *reset* operation.
+            DwfLibraryError: An error occurred while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalIOReset(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -41,7 +41,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
         This method does not have to be used if auto-configuration is enabled.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *configure* operation.
+            DwfLibraryError: An error occurred while executing the *configure* operation.
         """
         result = self.lib.FDwfDigitalIOConfigure(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -54,7 +54,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
         so this method does not return a value.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *status* operation.
+            DwfLibraryError: An error occurred while executing the *status* operation.
         """
         result = self.lib.FDwfDigitalIOStatus(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -76,7 +76,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that can be used as outputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output_enable_mask = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalIOOutputEnableInfo(self.hdwf, c_output_enable_mask)
@@ -101,7 +101,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             output_enable (int): A bitmask of pins that will be used as outputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalIOOutputEnableSet(self.hdwf, output_enable)
         if result != RESULT_SUCCESS:
@@ -123,7 +123,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that are currently configured as outputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output_enable = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalIOOutputEnableGet(self.hdwf, c_output_enable)
@@ -142,7 +142,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that can be used as outputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output_mask = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalIOOutputInfo(self.hdwf, c_output_mask)
@@ -161,7 +161,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             output (int): A bitmask of pins that will be driven high.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalIOOutputSet(self.hdwf, output)
         if result != RESULT_SUCCESS:
@@ -177,7 +177,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that are currently set to high.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalIOOutputGet(self.hdwf, c_output)
@@ -196,7 +196,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that can be used as inputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_input_mask = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalIOInputInfo(self.hdwf, c_input_mask)
@@ -218,7 +218,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that are currently read as high.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_input = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalIOInputStatus(self.hdwf, c_input)
@@ -243,7 +243,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that can be used as outputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output_enable_mask = typespec_ctypes.c_unsigned_long_long()
         result = self.lib.FDwfDigitalIOOutputEnableInfo64(self.hdwf, c_output_enable_mask)
@@ -268,7 +268,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             output_enable (int): A bitmask of pins that will be used as outputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalIOOutputEnableSet64(self.hdwf, output_enable)
         if result != RESULT_SUCCESS:
@@ -290,7 +290,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that are currently configured as outputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output_enable = typespec_ctypes.c_unsigned_long_long()
         result = self.lib.FDwfDigitalIOOutputEnableGet64(self.hdwf, c_output_enable)
@@ -309,7 +309,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that can be used as outputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output_mask = typespec_ctypes.c_unsigned_long_long()
         result = self.lib.FDwfDigitalIOOutputInfo64(self.hdwf, c_output_mask)
@@ -328,7 +328,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             output (int): A bitmask of pins that will be driven high.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalIOOutputSet64(self.hdwf, output)
         if result != RESULT_SUCCESS:
@@ -344,7 +344,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that are currently set to high.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output = typespec_ctypes.c_unsigned_long_long()
         result = self.lib.FDwfDigitalIOOutputGet64(self.hdwf, c_output)
@@ -363,7 +363,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that can be used as inputs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_input_mask = typespec_ctypes.c_unsigned_long_long()
         result = self.lib.FDwfDigitalIOInputInfo64(self.hdwf, c_input_mask)
@@ -385,7 +385,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
             int: A bitmask of pins that are currently read as high.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_input = typespec_ctypes.c_unsigned_long_long()
         result = self.lib.FDwfDigitalIOInputStatus64(self.hdwf, c_input)
