@@ -28,7 +28,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         """Reset the digital-out instrument.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *reset* operation.
+            DwfLibraryError: An error occurred while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalOutReset(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -41,7 +41,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             start (int): Whether to start/stop the instrument.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *configure* operation.
+            DwfLibraryError: An error occurred while executing the *configure* operation.
         """
         result = self.lib.FDwfDigitalOutConfigure(self.hdwf, start)
         if result != RESULT_SUCCESS:
@@ -56,7 +56,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             DwfState: The status of the |DigitalOut| instrument.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *status* operation.
+            DwfLibraryError: An error occurred while executing the *status* operation.
         """
         c_status = typespec_ctypes.DwfState()
         result = self.lib.FDwfDigitalOutStatus(self.hdwf, c_status)
@@ -72,7 +72,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             float: The digital-out clock frequency, in Hz.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_internal_clock_frequency = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalOutInternalClockInfo(self.hdwf, c_internal_clock_frequency)
@@ -91,7 +91,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             List[DwfTriggerSource]: A list of possible choices for the trigger source.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_trigger_source_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutTriggerSourceInfo(self.hdwf, c_trigger_source_bitset)
@@ -109,7 +109,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             trigger_source (DwfTriggerSource): The trigger source to be configured.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutTriggerSourceSet(self.hdwf, trigger_source.value)
         if result != RESULT_SUCCESS:
@@ -122,7 +122,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             DwfTriggerSource: The currently configured trigger source.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_trigger_source = typespec_ctypes.DwfTriggerSource()
         result = self.lib.FDwfDigitalOutTriggerSourceGet(self.hdwf, c_trigger_source)
@@ -138,7 +138,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             Tuple[float, float]: A tuple containing the minimal and maximal digital-out run duration, in seconds.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_run_duration_min = typespec_ctypes.c_double()
         c_run_duration_max = typespec_ctypes.c_double()
@@ -161,7 +161,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
                 The value 0 is special; it means *forever*.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutRunSet(self.hdwf, run_duration)
         if result != RESULT_SUCCESS:
@@ -174,7 +174,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             float: digital-out run-time, in seconds.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_run_duration = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalOutRunGet(self.hdwf, c_run_duration)
@@ -194,10 +194,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
 
         Returns:
             int: The number of clock cycles until the nest state transition of the
-                     |DigitalOut| instrument's state machine.
+            |DigitalOut| instrument's state machine.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_run_status = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalOutRunStatus(self.hdwf, c_run_status)
@@ -217,7 +217,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             precede a pulse-train output, expressed in seconds.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_wait_duration_min = typespec_ctypes.c_double()
         c_wait_duration_max = typespec_ctypes.c_double()
@@ -235,7 +235,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             wait_duration (float): Digital-out wait duration, in seconds.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutWaitSet(self.hdwf, wait_duration)
         if result != RESULT_SUCCESS:
@@ -248,7 +248,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             float: Digital-out wait duration, in seconds.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_wait_duration = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalOutWaitGet(self.hdwf, c_wait_duration)
@@ -262,10 +262,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
 
         Returns:
             Tuple[int, int]: A tuple containing the minimal and maximal repeat count for
-                digital-out pulse-sequence runs.
+            digital-out pulse-sequence runs.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_repeat_min = typespec_ctypes.c_unsigned_int()
         c_repeat_max = typespec_ctypes.c_unsigned_int()
@@ -284,7 +284,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
                 The value 0 is special; it means *forever*.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutRepeatSet(self.hdwf, repeat)
         if result != RESULT_SUCCESS:
@@ -298,7 +298,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             The value 0 is special; it means *forever*.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_repeat = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutRepeatGet(self.hdwf, c_repeat)
@@ -316,7 +316,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             int: The repeat count status.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_repeat_status = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutRepeatStatus(self.hdwf, c_repeat_status)
@@ -332,7 +332,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             trigger_slope (DwfTriggerSlope): The trigger slope to be configured.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutTriggerSlopeSet(self.hdwf, trigger_slope.value)
         if result != RESULT_SUCCESS:
@@ -345,7 +345,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             DwfTriggerSlope: The currently configured trigger slope.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_trigger_slope = typespec_ctypes.DwfTriggerSlope()
         result = self.lib.FDwfDigitalOutTriggerSlopeGet(self.hdwf, c_trigger_slope)
@@ -362,7 +362,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
                 pulse output sequence will wait until it receives a trigger.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutRepeatTriggerSet(self.hdwf, repeat_trigger_flag)
         if result != RESULT_SUCCESS:
@@ -373,7 +373,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
 
         Returns:
             bool: If True, not only the first, both also every successive run of the pulse output sequence
-                will wait until it receives a trigger.
+            will wait until it receives a trigger.
         """
         c_repeat_trigger = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutRepeatTriggerGet(self.hdwf, c_repeat_trigger)
@@ -389,7 +389,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             int: The number of digital output channels.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_channel_count = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutCount(self.hdwf, c_channel_count)
@@ -406,7 +406,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             enable_flag (bool): Whether to enable or disable the digital output.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutEnableSet(self.hdwf, channel_index, enable_flag)
         if result != RESULT_SUCCESS:
@@ -422,7 +422,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             bool: Whether the digital pin is enabled as an output.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_enable_flag = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutEnableGet(self.hdwf, channel_index, c_enable_flag)
@@ -438,7 +438,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             List[DwfDigitalOutOutput]: A list of valid output settings.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutOutputInfo(self.hdwf, channel_index, c_output_bitset)
@@ -456,7 +456,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             output_value (DwfDigitalOutOutput): The digital output setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutOutputSet(self.hdwf, channel_index, output_value.value)
         if result != RESULT_SUCCESS:
@@ -472,7 +472,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             DwfDigitalOutOutput: The digital output setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output_value = typespec_ctypes.DwfDigitalOutOutput()
         result = self.lib.FDwfDigitalOutOutputGet(self.hdwf, channel_index, c_output_value)
@@ -488,7 +488,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             List[DwfDigitalOutType]: A list of valid digital output types.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_type_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutTypeInfo(self.hdwf, channel_index, c_type_bitset)
@@ -506,7 +506,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             output_type (DwfDigitalOutType): The digital output type.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutTypeSet(self.hdwf, channel_index, output_type.value)
         if result != RESULT_SUCCESS:
@@ -522,7 +522,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             DwfDigitalOutType: The digital output type.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_output_type = typespec_ctypes.DwfDigitalOutType()
         result = self.lib.FDwfDigitalOutTypeGet(self.hdwf, channel_index, c_output_type)
@@ -538,7 +538,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             List[DwfDigitalOutIdle]: A list of valid digital idle options.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_idle_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutIdleInfo(self.hdwf, channel_index, c_idle_bitset)
@@ -556,7 +556,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             idle_mode (DwfDigitalOutIdle): The digital idle setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutIdleSet(self.hdwf, channel_index, idle_mode.value)
         if result != RESULT_SUCCESS:
@@ -572,7 +572,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             DwfDigitalOutIdle: The current digital idle setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_idle_mode = typespec_ctypes.DwfDigitalOutIdle()
         result = self.lib.FDwfDigitalOutIdleGet(self.hdwf, channel_index, c_idle_mode)
@@ -588,7 +588,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             Tuple[int, int]: The range of valid divider settings.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_divider_min = typespec_ctypes.c_unsigned_int()
         c_divider_max = typespec_ctypes.c_unsigned_int()
@@ -611,7 +611,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             divider_init (int): The divider init setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutDividerInitSet(self.hdwf, channel_index, divider_init)
         if result != RESULT_SUCCESS:
@@ -627,7 +627,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             int: The divider init setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_divider_init = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutDividerInitGet(self.hdwf, channel_index, c_divider_init)
@@ -644,7 +644,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             divider (int): The divider setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutDividerSet(self.hdwf, channel_index, divider)
         if result != RESULT_SUCCESS:
@@ -660,7 +660,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             int: The divider setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_divider = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutDividerGet(self.hdwf, channel_index, c_divider)
@@ -679,7 +679,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             Tuple[int, int]: The range of valid counter settings.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_counter_min = typespec_ctypes.c_unsigned_int()
         c_counter_max = typespec_ctypes.c_unsigned_int()
@@ -703,7 +703,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             counter_init (int): The initial counter setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutCounterInitSet(
             self.hdwf,
@@ -723,7 +723,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             and The initial counter setting.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_high = typespec_ctypes.c_int()
         c_counter_init = typespec_ctypes.c_unsigned_int()
@@ -742,11 +742,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
 
         Parameters:
             channel_index (int): The digital pin.
-            low_count (int): The number of cycles the signal should be High.
-            high_count (int): The number of cycles the signal should be Low.
+            low_count (int): The number of cycles the signal should be Low.
+            high_count (int): The number of cycles the signal should be High.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutCounterSet(self.hdwf, channel_index, low_count, high_count)
         if result != RESULT_SUCCESS:
@@ -757,10 +757,12 @@ class DigitalOut(AbstractDwfDeviceSubApi):
 
         Parameters:
             channel_index (int): The digital pin.
-            Tuple[int, int]: The number of cycles the signal should be High, Low.
+
+        Returns:
+            Tuple[int, int]: The number of cycles the signal should be Low, High.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_low_count = typespec_ctypes.c_unsigned_int()
         c_high_count = typespec_ctypes.c_unsigned_int()
@@ -782,7 +784,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             int: The number of custom data bits that can be specified for the channel.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_max_data_bits = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutDataInfo(self.hdwf, channel_index, c_max_data_bits)
@@ -799,7 +801,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             bits (str): The bits, as a string.
             tristate (bool): Whether to interpret the string as a tristate signal.
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
 
         if tristate:
@@ -829,7 +831,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             count_of_samples (int): (to be documented)
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutPlayDataSet(
             self.hdwf,
@@ -846,7 +848,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             playback_rate (float): The playback rate, in Hz.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalOutPlayRateSet(self.hdwf, playback_rate)
         if result != RESULT_SUCCESS:
