@@ -23,7 +23,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         """Reset the SPI protocol support.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *reset* operation.
+            DwfLibraryError: An error occurred while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalSpiReset(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -36,7 +36,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             frequency (float): SPI frequency, in Hz.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiFrequencySet(self.hdwf, frequency)
         if result != RESULT_SUCCESS:
@@ -50,7 +50,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 Digital channel (pin) for the clock signal.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiClockSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
@@ -73,7 +73,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 Digital channel (pin) for this data bit.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiDataSet(self.hdwf, spi_data_bit, channel_index)
         if result != RESULT_SUCCESS:
@@ -96,7 +96,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 Idle behavior of this bit.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
 
         result = self.lib.FDwfDigitalSpiIdleSet(self.hdwf, spi_data_bit, idle_mode.value)
@@ -119,7 +119,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 Refer to the slave device's datasheet to select the correct value.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiModeSet(self.hdwf, spi_mode)
         if result != RESULT_SUCCESS:
@@ -137,7 +137,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 0: LSB first, MSB last
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiOrderSet(self.hdwf, bit_order)
         if result != RESULT_SUCCESS:
@@ -167,7 +167,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 one of them should be low at any time.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalSpiSelect(self.hdwf, channel_index, level)
         if result != RESULT_SUCCESS:
@@ -191,7 +191,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the write/read operation.
+            DwfLibraryError: An error occurred while executing the write/read operation.
         """
         tx_list = list(tx)
 
@@ -235,7 +235,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the write/read operation.
+            DwfLibraryError: An error occurred while executing the write/read operation.
         """
         tx_list = list(tx)
 
@@ -279,7 +279,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the write/read operation.
+            DwfLibraryError: An error occurred while executing the write/read operation.
         """
 
         tx_list = list(tx)
@@ -324,7 +324,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the read operation.
+            DwfLibraryError: An error occurred while executing the read operation.
         """
 
         buffer_type = typespec_ctypes.c_unsigned_char * number_of_words
@@ -362,7 +362,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the read operation.
+            DwfLibraryError: An error occurred while executing the read operation.
         """
 
         buffer_type = typespec_ctypes.c_unsigned_short * number_of_words
@@ -400,7 +400,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the read operation.
+            DwfLibraryError: An error occurred while executing the read operation.
         """
 
         buffer_type = typespec_ctypes.c_unsigned_int * number_of_words
@@ -437,7 +437,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             int: The data-word received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the read operation.
+            DwfLibraryError: An error occurred while executing the read operation.
         """
         c_rx = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalSpiReadOne(self.hdwf, transfer_type, bits_per_word, c_rx)
@@ -461,7 +461,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The data-words to write.
 
         Raises:
-            DwfLibraryError: There was an error while executing the write operation.
+            DwfLibraryError: An error occurred while executing the write operation.
         """
         tx_list = list(tx)
 
@@ -495,7 +495,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The data-words to write.
 
         Raises:
-            DwfLibraryError: There was an error while executing the write operation.
+            DwfLibraryError: An error occurred while executing the write operation.
         """
         tx_list = list(tx)
 
@@ -529,7 +529,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The data-words to write.
 
         Raises:
-            DwfLibraryError: There was an error while executing the write operation.
+            DwfLibraryError: An error occurred while executing the write operation.
         """
         tx_list = list(tx)
 
@@ -562,7 +562,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The data-word to write.
 
         Raises:
-            DwfLibraryError: There was an error while executing the write operation.
+            DwfLibraryError: An error occurred while executing the write operation.
         """
         result = self.lib.FDwfDigitalSpiWriteOne(self.hdwf, transfer_type, bits_per_word, tx)
         if result != RESULT_SUCCESS:
