@@ -5,7 +5,7 @@ import ctypes
 
 from pydwf.core.auxiliary.dwf_function_signatures import dwf_function_signatures, dwf_version as expected_dwf_version
 from pydwf.core.auxiliary.exceptions import PyDwfError, DwfLibraryError
-from pydwf.core.auxiliary.enum_types import DwfErrorCode, DwfParameter
+from pydwf.core.auxiliary.enum_types import DwfErrorCode, DwfDeviceParameter
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.api.device_enumeration import DeviceEnumeration
@@ -33,7 +33,8 @@ class DwfLibrary:
         A single |DwfLibrary| instance should be created by a user of |pydwf| to serve as an entry point to all
         |pydwf| functionality.
 
-        When initializing a |DwfLibrary|, the shared library |libdwf| on which |pydwf| is built is loaded into memory.
+        When initializing a |DwfLibrary|, the shared library |libdwf| on top of which |pydwf| is built is loaded into
+        memory using Python's standard |ctypes:link| module.
 
         By default, a version check is executed to make sure that the shared library version corresponds exactly to
         the version that was used while developing and testing the current |pydwf| version (|libdwf-version|), and
@@ -160,7 +161,7 @@ class DwfLibrary:
         Raises:
             DwfLibraryError: the last error code cannot be retrieved.
         """
-        c_dwferc = typespec_ctypes.DWFERC()
+        c_dwferc = typespec_ctypes.DwfErrorCode()
         result = self._lib.FDwfGetLastError(c_dwferc)
         if result != RESULT_SUCCESS:
             # If the FDwfGetLastError call itself fails, we cannot get a proper error code or message.
@@ -211,11 +212,11 @@ class DwfLibrary:
         version = c_version.value.decode()
         return version
 
-    def paramSet(self, parameter: DwfParameter, value: int) -> None:
+    def paramSet(self, parameter: DwfDeviceParameter, value: int) -> None:
         """Configure a default parameter value.
 
-        Parameters are settings of a specific |DwfDevice|. Different |DwfDevice| instances
-        can have different values for each of the possible |DwfParameter:link| parameters.
+        Parameters are settings of a specific |DwfDevice|. Different |DwfDevice| instances can
+        have different values for each of the possible |DwfDeviceParameter:link| parameters.
 
         This method sets parameter values at the library level.
         They are used as default parameters for devices that are opened subsequently.
@@ -225,7 +226,7 @@ class DwfLibrary:
             for the specific parameter.
 
         Parameters:
-            parameter (DwfParameter): The parameter to set.
+            parameter (DwfDeviceParameter): The parameter to set.
             value (int): The desired parameter value.
 
         Raises:
@@ -235,11 +236,11 @@ class DwfLibrary:
         if result != RESULT_SUCCESS:
             raise self.exception()
 
-    def paramGet(self, parameter: DwfParameter) -> int:
+    def paramGet(self, parameter: DwfDeviceParameter) -> int:
         """Return a default parameter value.
 
-        Parameters are settings of a specific |DwfDevice|. Different |DwfDevice| instances
-        can have different values for each of the possible |DwfParameter:link| parameters.
+        Parameters are settings of a specific |DwfDevice|. Different |DwfDevice| instances can
+        have different values for each of the possible |DwfDeviceParameter:link| parameters.
 
         This method retrieves parameter values at the library level.
         They are used as default parameters for devices that are opened subsequently.
