@@ -19,5 +19,5 @@ class AbstractDwfLibrarySubApi:
 
     @property
     def lib(self):
-        """Return the ctypes library."""
+        """Return the |ctypes:link| library."""
         return self.dwf.lib
