@@ -1,4 +1,4 @@
-"""Implementation of the |pydwf.utilities.open_dwf_device| function."""
+"""Implementation of the |pydwf.utilities.openDwfDevice| function."""
 
 from typing import Optional, Callable, Dict, Any
 
@@ -8,11 +8,11 @@ from pydwf.core.auxiliary.enum_types import DwfEnumConfigInfo, DwfEnumFilter
 from pydwf.core.auxiliary.exceptions import PyDwfError
 
 
-def open_dwf_device(
+def openDwfDevice(
             dwf: DwfLibrary,
             enum_filter: Optional[DwfEnumFilter] = None,
             serial_number: Optional[str] = None,
-            configuration_fitness_func: Optional[Callable[[Dict[DwfEnumConfigInfo, Any]], Optional[int]]] = None
+            score_func: Optional[Callable[[Dict[DwfEnumConfigInfo, Any]], Optional[int]]] = None
         ) -> DwfDevice:
     """Open a device identified by its serial number, optionally selecting a preferred configuration.
 
@@ -23,13 +23,13 @@ def open_dwf_device(
        To do this, device enumeration is performed, resulting in a list of all reachable Digilent Waveforms devices.
 
        For this initial enumeration process the *enum_filter* can be used to only list certain types of devices
-       (for example, only Analog Discovery 2 devices, or Dgitial Discovery devices). If omitted (the default),
+       (for example, only Analog Discovery 2 devices, or Digital Discovery devices). If omitted (the default),
        all Digilent Waveforms devices will be listed.
 
        Then, if the *serial_number* parameter is given, the list will be filtered to exclude devices whose serial
        numbers do not match.
 
-       If the list that remains has a single device, this device will be used. If not, a |PyDwfError| is reported.
+       If the list that remains has a single device, this device will be used. If not, a |PyDwfError:link| is raised.
 
     2. The next step is to select a *device configuration* for the selected device.
 
@@ -40,19 +40,19 @@ def open_dwf_device(
        while another configuration may support a lot of buffering memory for the |DigitalOut| instrument.
 
        For many use cases, the default configuration that provides a balanced tradeoff works fine.
-       If no *configuration_fitness_func* is provided, this default configuration will be used.
+       If no *score_func* is provided, this default configuration will be used.
 
-       If a *configuration_fitness_func* is provided, it should be a function (or lambda expression) that
+       If a *score_func* is provided, it should be a function (or lambda expression) that
        takes a single parameter *configuration_info*, which is a dictionary with |DwfEnumConfigInfo:link| keys,
        and parameters values for a specific device configuration.
 
        The function should return *None* if the configuration is entirely unsuitable, or otherwise a score
-       that reflects the 'desirability' or 'fitness' of that particular configuration for the task at hand.
+       that reflects the suitability of that particular configuration for the task at hand.
 
-       The *open_dwf_device* function will go through all available device configurations, construct a dictionary
-       of all parameters that describe the configuration, call the *configuration_fitness_func* with that dictionary,
+       The *openDwfDevice* function will go through all available device configurations, construct a dictionary
+       of all parameters that describe the configuration, call the *score_func* with that dictionary as a parameter,
        and examine the score value it returns. If multiple suitable device configurations are found (i.e., the
-       *configuration_fitness_func* does not return None), it will select the configuration with the highest score.
+       *score_func* does not return None), it will select the configuration with the highest score.
 
        This may all sounds pretty complicated, but in practice this parameter is quite easy to define for most
        common use-cases.
@@ -62,20 +62,20 @@ def open_dwf_device(
        .. code-block:: python
 
           from pydwf import DwfEnumConfigInfo
-          from pydwf.utilities import open_dwf_device
+          from pydwf.utilities import openDwfDevice
 
           def maximize_analog_in_buffer_size(config_parameters):
               return config_parameters[DwfEnumConfigInfo.AnalogInBufferSize]
 
-          with open_dwf_device(dwf,
-                    configuration_fitness_func = maximize_analog_in_buffer_size) as device:
+          with openDwfDevice(dwf, score_func = maximize_analog_in_buffer_size) as device:
               use_device_with_big_analog_in_buffer(device)
 
     3. As a final step, the selected device is opened using the selected device configuration, and the
        newly instantiated |DwfDevice:link| instance is returned.
 
     Note:
-        This method takes several seconds to complete.
+        This method can take several seconds to complete. This long duration is caused by the use
+        of the |DeviceEnum.enumerateDevices:link| method.
 
     Parameters:
         dwf (DwfLibrary): The |DwfLibrary:link| used to open the device.
@@ -84,8 +84,8 @@ def open_dwf_device(
             In None, enumerate all devices.
         serial_number (str): The serial number of the device to be opened.
             Digilent Waveforms device serial numbers consist of 12 hexadecimal digits.
-        configuration_fitness_func (Optional[Callable[[Dict[DwfEnumConfigInfo, Any]]):
-            A function to score the configurations of the selected device.
+        score_func (Optional[Callable[[Dict[DwfEnumConfigInfo, Any]], Optional[int]]]):
+            A function to score a configuration of the selected device.
             See the description above for details.
 
     Returns:
@@ -136,33 +136,34 @@ def open_dwf_device(
 
     device_index = candidate_devices[0]
 
-    if configuration_fitness_func is None:
-        # If no 'configuration_fitness_func' was specified, just open the first (default) one.
+    if score_func is None:
+        # If no 'score_func' was specified, just open the device with the default (first) configuration.
         return dwf.deviceControl.open(device_index)
 
-    # The caller specified a 'configuration_fitness_func'.
-    # We will examine all configuration and pick the one that has the highest fitness.
+    # The caller specified a 'score_func'.
+    # We will examine all configuration and pick the one that has the highest score.
 
     num_config = dwf.deviceEnum.enumerateConfigurations(device_index)
 
     best_configuration_index = None
-    best_configuration_fitness = None
+    best_configuration_score = None
 
     for configuration_index in range(num_config):
 
         configuration_info = {
-            configuration_parameter: dwf.deviceEnum.configInfo(configuration_index, configuration_parameter)
+            configuration_parameter:
+                dwf.deviceEnum.configInfo(configuration_index, configuration_parameter)
                 for configuration_parameter in DwfEnumConfigInfo
         }
 
-        configuration_fitness = configuration_fitness_func(configuration_info)
+        configuration_score = score_func(configuration_info)
 
-        if configuration_fitness is None:
+        if configuration_score is None:
             continue
 
-        if best_configuration_index is None or configuration_fitness > best_configuration_fitness:
+        if best_configuration_index is None or configuration_score > best_configuration_score:
             best_configuration_index = configuration_index
-            best_configuration_fitness = configuration_fitness
+            best_configuration_score = configuration_score
 
     if best_configuration_index is None:
         raise PyDwfError("No acceptable configuration was found.")
